# Running environments

The easiest way to run some environments is to dive into examples.
The complete installation of the AI Traineree package includes the [OpenAI gym](https://gym.openai.com/envs/).
This means that you should be able to simply run one of the provided examples in `../examples/`.
Go ahead and change some parameters, and see what happens.

## OpenAI Gym

### Classic


### MuJoCo

Nope. The author is not a student and doesn't work for wealthy company.
Hopefully people